pub struct NativeInstanceLaunchOverlay { /* private fields */ }Expand description
Host-only launch mutations applied to one exact native PTY instance.
The overlay does not implement Debug because environment values and argv
may contain secret material. It is validated and retained without crossing
the wire or durable state boundaries.
Implementations
Sourceimpl NativeInstanceLaunchOverlay
impl NativeInstanceLaunchOverlay
pub fn new( agent_id: AgentId, transport: TransportKind, environment: Vec<EnvMutation>, extra_args: Vec<OsString>, ) -> Result<Self, NativeLaunchProfileError>
Sourceimpl NativeInstanceLaunchOverlay
impl NativeInstanceLaunchOverlay
Sourcepub fn append_extra_args(
&mut self,
extra_args: Vec<OsString>,
) -> Result<(), NativeLaunchProfileError>
pub fn append_extra_args( &mut self, extra_args: Vec<OsString>, ) -> Result<(), NativeLaunchProfileError>
Append validated argv (Codex -c network_access merge onto an
existing instance overlay).